
import React, { useState } from 'react';
import { Link } from 'react-router-dom';
import { Button } from '@/components/ui/button';
import { MessageSquare, Users, BarChart, Star, ArrowRight } from 'lucide-react';
import { useAuth } from '@/context/AuthContext';

// Préchargement de l'image LCP directement
const HERO_IMAGE_URL = "/lovable-uploads/55d05d5a-40b6-44b9-9e7a-40f528b9099f.png";
const TRUSTPILOT_IMAGE_URL = "/lovable-uploads/29e398f0-3d46-4373-bf8f-d5ea8831936d.png";

const HeroSection = () => {
  const { user } = useAuth();
  const [isLoading, setIsLoading] = useState(false);
  
  const handleTalkToConfidly = () => {
    setIsLoading(true);
    setTimeout(() => {
      setIsLoading(false);
    }, 300);
  };
  
  return (
    <section className="py-8 md:py-16 bg-gradient-to-b from-stripe-light to-white">
      <div className="container max-w-5xl mx-auto px-4">
        <div className="grid grid-cols-1 md:grid-cols-2 gap-8 md:gap-12 items-center">
          <div className="space-y-6">
            {/* Optimisation du titre pour le LCP */}
            <h1 
              className="text-4xl font-bold leading-tight text-zinc-950 md:text-5xl"
              id="hero-title"
            >
              Transform Your Emotional Health with AI That <span className="text-stripe-blue">Understands You</span>
            </h1>
            <p className="text-xl text-stripe-gray-dark">
              Confidly AI recognizes your feelings and helps you achieve balance and peace
            </p>
            
            {/* Talk to Confidly Button */}
            <div className="bg-white p-6 rounded-xl shadow-md border border-stripe-gray-light">
              <div className="space-y-4">
                <Button asChild size="lg" className="w-full shadow-md hover:shadow-lg transition-all flex items-center justify-center py-7 text-lg" variant="stripe-blue" disabled={isLoading}>
                  {user ? (
                    <Link to="/chat">
                      <ArrowRight className="mr-2 h-6 w-6 font-bold" strokeWidth={2.5} /> Start Your Emotional Reset
                    </Link>
                  ) : (
                    <Link to="/signup">
                      <ArrowRight className="mr-2 h-6 w-6 font-bold" strokeWidth={2.5} /> Start Your Emotional Reset
                    </Link>
                  )}
                </Button>
                
                <div className="flex justify-center mt-3">
                  <img 
                    src={TRUSTPILOT_IMAGE_URL}
                    alt="Trustpilot Rating 4.8 from 347 reviews" 
                    className="h-auto w-full max-w-[250px] object-contain" 
                    width="250"
                    height="40"
                    loading="eager"
                    fetchPriority="high"
                    decoding="async"
                  />
                </div>
              </div>
            </div>
          </div>
          
          <div className="bg-white p-6 rounded-xl shadow-xl border border-stripe-gray-light animate-fade-in hover:shadow-2xl transition-shadow duration-300 ease-in-out">
            <div className="w-full aspect-video rounded-lg">
              {/* Image de la femme souriante - optimisée pour LCP */}
              <img 
                src={HERO_IMAGE_URL}
                alt="Woman smiling while using Confidly on her phone" 
                className="w-full h-auto rounded-lg object-cover"
                width="500"
                height="375"
                loading="eager" 
                fetchPriority="high"
                decoding="async"
              />
            </div>
            
            {/* Stats Section (3 columns) - Information importante mais non critique pour le LCP */}
            <div className="grid grid-cols-3 gap-4 mt-6 pt-5 border-t border-stripe-gray-light bg-stripe-light/30 p-4 rounded-lg">
              <div className="flex flex-col items-center text-center">
                <div className="flex items-center justify-center mb-2 text-stripe-blue">
                  <Users className="h-6 w-6 mr-1" />
                </div>
                <h3 className="text-xl font-bold text-stripe-dark">4592</h3>
                <p className="text-sm text-stripe-gray-dark font-medium">served</p>
              </div>
              <div className="flex flex-col items-center text-center">
                <div className="flex items-center justify-center mb-2 text-stripe-blue">
                  <BarChart className="h-6 w-6 mr-1" />
                </div>
                <h3 className="text-xl font-bold text-stripe-dark">93%</h3>
                <p className="text-sm text-stripe-gray-dark font-medium">report effective</p>
              </div>
              <div className="flex flex-col items-center text-center">
                <div className="flex items-center justify-center mb-2 text-stripe-blue">
                  <Star className="h-6 w-6 mr-1" />
                </div>
                <h3 className="text-xl font-bold text-stripe-dark">+9K</h3>
                <p className="text-sm text-stripe-gray-dark font-medium">5 star reviews</p>
              </div>
            </div>
          </div>
        </div>
      </div>
    </section>
  );
};

export default HeroSection;
